@@ -10,7 +10,7 @@ from mptt.admin import TreeRelatedFieldListFilter
 from django.utils.html import format_html
 from django.utils.translation import ugettext_lazy as _
 from django_readedit_switch_admin.admin import DjangoReadEditSwitchAdmin
-from django_changelist_toolbar_admin.admin import DjangoChangelistToolbarAdminMixin
+from django_changelist_toolbar_admin.admin import DjangoChangelistToolbarAdmin
 from django_visit_on_site_in_new_window.admin import DjangoVisitOnSiteInNewWindowAdmin
 from django_cards_admin.admin import DjangoCardsAdminMixin
 from django_msms_admin.admin import DjangoMsmsAdmin
@@ -235,7 +235,7 @@ class PageWidgetInline(DjangoReadEditSwitchAdmin, admin.TabularInline):
 
 class PageAdmin(
         DjangoReadEditSwitchAdmin,
-        DjangoChangelistToolbarAdminMixin,
+        DjangoChangelistToolbarAdmin,
         DjangoVisitOnSiteInNewWindowAdmin,
         DjangoTabbedChangeformAdmin,
         DraggableMPTTAdmin,
@@ -318,7 +318,7 @@ class ArticleAdmin(
         DjangoReadEditSwitchAdmin,
         DraggableMPTTAdmin,
         DjangoTabbedChangeformAdmin,
-        DjangoChangelistToolbarAdminMixin,
+        DjangoChangelistToolbarAdmin,
         admin.ModelAdmin):
     form = ArticleForm
     list_display = ["tree_actions", "indented_title", "published", "published_time", "label"]
