@@ -17,13 +17,17 @@ def site(request, site_code):
         raise Http404()
 
 def page(request, site_code, page_code):
-    page = get_object_or_404(Page, published=True, site__code=site_code, code=page_code)
+    page = get_object_or_404(Page,site__code=site_code, code=page_code)
+    if not page.is_published:
+        raise Http404()
     context = {
         "request": request,
         "site_code": site_code,
         "page_code": page_code,
         "site": page.site,
         "page": page,
+        "title": page.site.name + " | " + page.name
     }
     html = page.render(request, context)
     return HttpResponse(html)
+
